@@ -8,8 +8,6 @@ from logging import handlers
 from functools import wraps
 
 
-__updated__ = '2020-12-04 01:57:49'
-
 DATEFORMAT_STD = "%Y-%m-%d %H:%M:%S"
 DATEFORMAT_DEV = "%H:%M:%S"
 
@@ -64,11 +62,11 @@ def NEWRUN():
 
 def class_init_notification(logger, in_class, use=None):
     if use == 'repr':
-        _string = repr(in_class)
+        _string = f"'{repr(in_class)}'"
     elif use == 'str':
-        _string = str(in_class)
+        _string = f"'{str(in_class)}'"
     else:
-        _string = in_class.__class__.__name__
+        _string = f"'{in_class.__class__.__name__}'"
     return logger.debug("finished initiating %s class", _string)
 
 
@@ -83,7 +81,7 @@ def completed(function_name):
 def aux_logger(in_name):
     in_name = in_name.split('.')
     in_name = in_name[-1]
-    return logging.getLogger('main').getChild(in_name)
+    return logging.getLogger('main.' + in_name)
 
 
 # def main_logger(in_file_name, in_level, in_back_up=2):
@@ -101,10 +99,23 @@ def aux_logger(in_name):
 
 #     return _out
 
+class CustomFormatter(logging.Formatter):
+    """ Custom Formatter does these 2 things:
+    1. Overrides 'funcName' with the value of 'func_name_override', if it exists.
+    2. Overrides 'filename' with the value of 'file_name_override', if it exists.
+    """
+
+    def format(self, record):
+        if hasattr(record, 'func_name_override'):
+            record.funcName = record.func_name_override
+        if hasattr(record, 'file_name_override'):
+            record.filename = record.file_name_override
+        return super().format(record)
+
 
 def _each_run_file_rotate_handler(in_file_name, in_back_up):
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = logging.Formatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
     handler = handlers.RotatingFileHandler(in_file_name, mode='a', backupCount=in_back_up, maxBytes=10 * (1024 * 1024))
     handler.namer = std_namer
     handler.setFormatter(formatter)
@@ -113,7 +124,7 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 def _stdout_handler():
     _date_format = DATEFORMAT_DEV if os.getenv('IS_DEV') == "1" else DATEFORMAT_STD
-    formatter = logging.Formatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime}|{levelname:^9}|{threadName:^25}|{lineno:^7}| {name:<30}|{funcName:^25}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
@@ -158,9 +169,10 @@ def _is_appdata_object(in_object):
 
 
 def std_namer(name):
-    _nameparts = name.split('.')
+    _nameparts = name.replace('.log', '').split('.')
     _path, _basename = pathmaker(_nameparts[0]).rsplit('/', 1)
-    return pathmaker(_path, 'old_logs', f'{_basename}_{_nameparts[2]}.{_nameparts[1]}')
+    extra_nameparts = '_'.join([_nameparts[i] for i in range(len(_nameparts)) if i != 0])
+    return pathmaker(_path, 'old_logs', f'{_basename}_{extra_nameparts}.log')
 
 
 def log_folderer(in_log_file_name, in_main_log_folder=None):
